@@ -2,7 +2,7 @@
 #'
 #' This is normally an internal function, but it can be overloaded to extend \code{simr} to other packages.
 #'
-#' @param object an object to simulare from, usually a fitted model.
+#' @param object an object to simulate from, usually a fitted model.
 #' @param ... additional options.
 #'
 #' @return a vector containing simulated response values (or, for models  with a multivariate response such as
@@ -38,7 +38,33 @@ doSim.merMod <- function(object, ...) {
 
     simData <- getData(object)
 
-    simulate(formula(object)[-2], newparams=simParams, newdata=simData, family=family(object), ...)[[1]]
+    # check weights
+    w <- weights(object)
+    if(!is.null(w)) if(length(w) != nrow(simData)) {
+
+        if(length(unique(w)) != 1) {
+
+            if(cbindResponse(object)) {
+
+                w <- NULL
+
+            } else {
+
+                stop("Non-uniform weights are not supported yet.")
+            }
+
+        } else {
+
+            w <- rep(w[1], nrow(simData))
+        }
+    }
+
+    simulate(
+        formula(object),
+        newparams=simParams,
+        newdata=simData,
+        family=family(object),
+        weights=w, ...)[[1]]
 }
 
 #' @export
